@@ -1,7 +1,7 @@
 package Yukki;
-$Yukki::VERSION = '0.991_001'; # TRIAL
+$Yukki::VERSION = '0.991_002'; # TRIAL
 
-$Yukki::VERSION = '0.991001';use v5.24;
+$Yukki::VERSION = '0.991002';use v5.24;
 use utf8;
 use Moo;
 
@@ -16,7 +16,7 @@ use Crypt::SaltedHash;
 use List::Util qw( any );
 use Type::Params qw( validate );
 use Type::Utils;
-use Types::Standard qw( Dict HashRef Str Undef slurpy );
+use Types::Standard qw( Dict HashRef Str Maybe slurpy Optional );
 use Path::Tiny;
 use Types::Path::Tiny qw( Path );
 
@@ -85,12 +85,22 @@ sub _locate {
     my ($self, $type, $base, @extra_path) = @_;
 
     my $base_path = $self->settings->$base;
+    my $root_path;
+
     if ($base_path !~ m{^/}) {
-        return path($self->settings->root, $base_path, @extra_path);
+        $root_path = path($self->settings->root, $base_path);
     }
     else {
-        return path($base_path, @extra_path);
+        $root_path = path($base_path);
     }
+
+    my $located_path = $root_path->child(@extra_path);
+
+    # Small safety mechanism
+    die "attempted to lookup an illegal $base path: ", join('/', @extra_path)
+        unless $root_path->subsumes($located_path);
+
+    return $located_path;
 }
 
 sub locate {
@@ -109,16 +119,23 @@ sub check_access {
     my ($self, $opt)
         = validate(\@_, class_type(__PACKAGE__),
             slurpy Dict[
-                user       => Undef|HashRef,
-                repository => Str,
+                user       => Maybe[class_type('Yukki::User')],
+                special    => Optional[Str],
+                repository => Optional[Str],
                 needs      => AccessLevel,
-            ]);
-    my ($user, $repository, $needs) = @{$opt}{qw( user repository needs )};
+            ]
+        );
+    my ($user, $repository, $special, $needs)
+        = @{$opt}{qw( user repository special needs )};
+
+    $repository //= '-';
+    $special //= '-';
 
     # Always grant none
     return 1 if $needs eq 'none';
 
-    my $config = $self->settings->repositories->{$repository};
+    my $config = $self->settings->repositories->{$repository}
+              // $self->settings->special_privileges->{$special};
 
     return '' unless $config;
 
@@ -185,7 +202,7 @@ Yukki - Yet Uh-nother wiki
 
 =head1 VERSION
 
-version 0.991_001
+version 0.991_002
 
 =head1 DESCRIPTION
 
