@@ -1,7 +1,7 @@
 package Yukki::Model::Repository;
-$Yukki::Model::Repository::VERSION = '0.991_001'; # TRIAL
+$Yukki::Model::Repository::VERSION = '0.991_002'; # TRIAL
 
-$Yukki::Model::Repository::VERSION = '0.991001';use v5.24;
+$Yukki::Model::Repository::VERSION = '0.991002';use v5.24;
 use utf8;
 use Moo;
 
@@ -36,7 +36,16 @@ has repository_settings => (
     lazy        => 1,
     default     => sub {
         my $self = shift;
-        $self->app->settings->repositories->{$self->name};
+        my $repo_config = $self->app->settings->repositories->{$self->name};
+
+        if (!$repo_config) {
+            my $file = $self->app->locate('repo_path', $self->name);
+            $repo_config = Yukki::Settings::Repository->load_yaml(
+                $file->slurp_utf8
+            );
+        }
+
+        return $repo_config;
     },
     handles     => {
         'title'  => 'name',
@@ -493,6 +502,16 @@ END_OF_STUB_MAIN
     return;
 }
 
+
+sub clone_repository {
+    my ($self, $origin) = @_;
+
+    my $repository_path = ''.$self->repository_path;
+    Git::Repository->run('clone', '--bare', $origin, $repository_path);
+
+    return;
+}
+
 1;
 
 __END__
@@ -507,7 +526,7 @@ Yukki::Model::Repository - model for accessing objects in a git repository
 
 =head1 VERSION
 
-version 0.991_001
+version 0.991_002
 
 =head1 SYNOPSIS
 
@@ -732,6 +751,12 @@ The types are:
 
 Run on an empty repository to create an empty one.
 
+=head2 clone_repository
+
+    $self->clone_repository($origin);
+
+Given a remote repository URI to clone from in C<$origin>, initialize the local repository from a clone of the remote one.
+
 =head1 AUTHOR
 
 Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
