@@ -1,13 +1,14 @@
 package Yukki::Settings;
-$Yukki::Settings::VERSION = '0.991_001'; # TRIAL
+$Yukki::Settings::VERSION = '0.991_002'; # TRIAL
 
-$Yukki::Settings::VERSION = '0.991001';use v5.24;
+$Yukki::Settings::VERSION = '0.991002';use v5.24;
 use utf8;
 use Moo;
 
 use Types::Path::Tiny qw( Path );
 use Types::Standard qw( Str );
-use Yukki::Types qw( RepositoryMap YukkiSettingsAnonymous );
+use Yukki::Settings::Repository;
+use Yukki::Types qw( PrivilegesMap RepositoryMap YukkiSettingsAnonymous );
 
 use namespace::clean;
 
@@ -58,6 +59,15 @@ has anonymous => (
 );
 
 
+has repo_path => (
+    is          => 'ro',
+    isa         => Path,
+    required    => 1,
+    coerce      => 1,
+    default     => 'var/db/repos',
+);
+
+
 has repositories => (
     is          => 'ro',
     isa         => RepositoryMap,
@@ -67,9 +77,9 @@ has repositories => (
 
 {
     package Yukki::Settings::Anonymous;
-$Yukki::Settings::Anonymous::VERSION = '0.991_001'; # TRIAL
+$Yukki::Settings::Anonymous::VERSION = '0.991_002'; # TRIAL
 
-$Yukki::Settings::Anonymous::VERSION = '0.991001';use Moo;
+$Yukki::Settings::Anonymous::VERSION = '0.991002';use Moo;
     use Types::Standard qw( Str );
     use Yukki::Types qw( EmailAddress );
 
@@ -89,70 +99,14 @@ $Yukki::Settings::Anonymous::VERSION = '0.991001';use Moo;
     );
 }
 
-{
-    package Yukki::Settings::Repository;
-$Yukki::Settings::Repository::VERSION = '0.991_001'; # TRIAL
 
-$Yukki::Settings::Repository::VERSION = '0.991001';use Moo;
-    use Types::Path::Tiny qw( Path );
-    use Types::Standard qw( ArrayRef Int Str );
-
-    has repository => (
-        is          => 'ro',
-        isa         => Path,
-        required    => 1,
-        coerce      => 1,
-    );
-
-    has site_branch => (
-        is          => 'ro',
-        isa         => Str,
-        required    => 1,
-        default     => 'refs/heads/master',
-    );
-
-    has name => (
-        is          => 'ro',
-        isa         => Str,
-        required    => 1,
-    );
-
-    has default_page => (
-        is          => 'ro',
-        isa         => Path,
-        required    => 1,
-        coerce      => 1,
-        default     => 'home.yukki',
-    );
-
-    has sort => (
-        is          => 'ro',
-        isa         => Int,
-        required    => 1,
-        default     => 50,
-    );
-
-    has anonymous_access_level => (
-        is          => 'ro',
-        isa         => Yukki::Types::AccessLevel,
-        required    => 1,
-        default     => 'none',
-    );
-
-    has read_groups => (
-        is          => 'ro',
-        isa         => Str|ArrayRef[Str],
-        required    => 1,
-        default     => 'NONE',
-    );
-
-    has write_groups => (
-        is          => 'ro',
-        isa         => Str|ArrayRef[Str],
-        required    => 1,
-        default     => 'NONE',
-    );
-}
+has special_privileges => (
+    is          => 'ro',
+    isa         => PrivilegesMap,
+    required    => 1,
+    coerce      => 1,
+    default     => sub { +{} },
+);
 
 1;
 
@@ -168,7 +122,7 @@ Yukki::Settings - provides structure and validation to settings in yukki.conf
 
 =head1 VERSION
 
-version 0.991_001
+version 0.991_002
 
 =head1 DESCRIPTION
 
@@ -212,45 +166,37 @@ This is the email address to use when an anonymous user makes a change to a wiki
 
 =back
 
+=head2 repo_path
+
+This is the folder where repository configuraiton files can be found. This path is intended for application managed repository configuration files. If you want to manage your repositories from the command-line instead, store the repository configurations under the C<repository> key in the main settings file.
+
 =head2 repositories
 
 This is a section under which each repository is configured. The keys under here are the name found in the URL. It is also the name to use when running the F<yukki-git-init> and other repository-related commands.
 
-Each repository configuraiton should provide the following configruation keys.
+Repository configurations may be stored either in the main Yukki configuration file under the C<repositories> key or as individual files located in the directory named in the C<repo_path> key. If a configuration is named in both places, the one in the main settings file will always be used.
+
+Each repository configuration should provide the following configruation keys.
+
+=head2 special_privileges
+
+This section of the settings configures which groups grant special privileges. These special privileges grant access to view or change the configuration from within the application. By default, no one has these privileges, effectively disabling any in-app administrative features.
+
+The grants for each here are identical to that available to repositories:
 
 =over
 
-=item repository
-
-This is required. This is the name of the git repository folder found under C<repository_path>.
-
-=item site_branch
-
-This is teh name of the branch that will contain the wiki's files. The default is C<refs/heads/master>. You could actually use the same git repository for multiple Yukki repositories by using different branches. If you want to do it that way for some reason. Unless you know what you're doing, you probably don't want to do that.
-
-=item name
-
-This is a human readable title for the repository.
-
-=item default_page
-
-This is the name of the main repository index.
-
 =item anonymous_access_level
 
-This should be set to one of the following: read, write, or none. This settings decides how much access an anonymous user has when visiting your wiki.
+This names the access level anonymous users have. Obviously, it would generally be unwise for this to be anything but "none" for adminsitrative functions, but "read" and "write" are other possible values.
 
 =item read_groups
 
-This may be set to the word "ANY" or the word "NONE" or to an array of group names.
-
-If set to ANY, any logged user may read this repository. If set to NONE, read access is not granted to any logged user (though if C<anonymous_access_level> or C<write_groups> grant a user access, the user will be able to read the repository).
-
-If an array of one or more group names are given, the users with any of those groups will be able to read the repository.
+Names the list of groups that are granted permission to perform read-only actions. This may also be set to "ANY" to specify that any logged user may perform this action or "NONE" to specify that no logged user may perform this action.
 
 =item write_groups
 
-THe possible values that may be set are identicl to C<read_groups>. This setting determines who has permission to edit pages and upload files to the repository.
+Names the list of groups that are granted permission to perform read-write actions. As with read, this may be set to "ANY" and "NONE" with the same meaning.
 
 =back
 
