@@ -1,7 +1,7 @@
 package Yukki::TextUtil;
-$Yukki::TextUtil::VERSION = '0.991_001'; # TRIAL
+$Yukki::TextUtil::VERSION = '0.991_002'; # TRIAL
 
-$Yukki::TextUtil::VERSION = '0.991001';use v5.24;
+$Yukki::TextUtil::VERSION = '0.991002';use v5.24;
 use utf8;
 
 use Encode ();
@@ -25,13 +25,13 @@ use Sub::Exporter -setup => {
 
 sub dump_file {
     my ($file, $data) = @_;
-    path($file)->spew(YAML::Dump($data));
+    path($file)->spew_utf8(YAML::Dump($data));
 }
 
 
 sub load_file {
     my ($file) = @_;
-    YAML::Load(path($file)->slurp);
+    YAML::Load(path($file)->slurp_utf8);
 }
 
 
@@ -53,7 +53,7 @@ Yukki::TextUtil - Utilities to help make everything happy UTF-8
 
 =head1 VERSION
 
-version 0.991_001
+version 0.991_002
 
 =head1 DESCRIPTION
 
