@@ -1,7 +1,7 @@
 package Yukki::Types;
-$Yukki::Types::VERSION = '0.991_001'; # TRIAL
+$Yukki::Types::VERSION = '0.991_002'; # TRIAL
 
-$Yukki::Types::VERSION = '0.991001';use v5.24;
+$Yukki::Types::VERSION = '0.991002';use v5.24;
 use utf8;
 
 use Type::Library -base, -declare => qw(
@@ -9,6 +9,7 @@ use Type::Library -base, -declare => qw(
     NavigationLinks NavigationMenuMap
     BaseURL BaseURLEnum BreadcrumbLinks RepositoryMap
     PluginConfig PluginList
+    PrivilegesMap
     EmailAddress YukkiSettings
     YukkiWebSettings YukkiSettingsAnonymous
 );
@@ -27,7 +28,7 @@ use namespace::clean;
 
 declare LoginName,
     as Str,
-    where { /^[a-z0-9]+$/ },
+    where { /^[a-zA-Z0-9_-]{3,20}$/ },
     message { "login name $_ must only contain letters and numbers" };
 
 
@@ -84,6 +85,21 @@ coerce RepositoryMap,
     };
 
 
+my $Privileges = class_type 'Yukki::Settings::Privileges';
+declare PrivilegesMap,
+    as HashRef[$Privileges];
+
+coerce PrivilegesMap,
+    from HashRef,
+    via {
+        my $source = $_;
+        +{
+            map { $_ => Yukki::Settings::Privileges->new($source->{$_}) }
+                keys %$source
+        }
+    };
+
+
 declare PluginConfig,
     as ArrayRef[HashRef],
     where { all { defined $_->{module} } @$_ };
@@ -138,7 +154,7 @@ Yukki::Types - standard types for use in Yukki
 
 =head1 VERSION
 
-version 0.991_001
+version 0.991_002
 
 =head1 SYNOPSIS
 
@@ -196,6 +212,10 @@ This is an array of hashes formatted like:
 
 This is a hash of L<Yukki::Settings::Repository> objects.
 
+=head2 PrivilegeMap
+
+This is a hash of L<Yukki::Settings::Privileges> objects.
+
 =head2 PluginConfig
 
 A plugin configuration is an array of hashes. Each hash must have at least one key named "module" defined.
