@@ -1,7 +1,7 @@
 package Yukki::Web;
-$Yukki::Web::VERSION = '0.991_001'; # TRIAL
+$Yukki::Web::VERSION = '0.991_002'; # TRIAL
 
-$Yukki::Web::VERSION = '0.991001';use v5.24;
+$Yukki::Web::VERSION = '0.991002';use v5.24;
 use utf8;
 use Moo;
 
@@ -149,6 +149,7 @@ sub dispatch {
         }) unless $self->check_access(
                 user       => $ctx->session->{user},
                 repository => $match->mapping->{repository} // '-',
+                special    => $match->mapping->{special} // '-',
                 needs      => $access_level_needed,
             );
 
@@ -211,7 +212,7 @@ sub dispatch {
         else {
             warn "ISE: $_";
 
-            $response = http_exception($_, {
+            $response = http_exception("Oh darn. Something went wrong.", {
                 status           => 'InternalServerError',
                 show_stack_trace => 0,
             })->as_psgi($env);
@@ -265,7 +266,7 @@ Yukki::Web - the Yukki web server
 
 =head1 VERSION
 
-version 0.991_001
+version 0.991_002
 
 =head1 DESCRIPTION
 
