@@ -1,7 +1,7 @@
 package Yukki::Web::Router;
-$Yukki::Web::Router::VERSION = '0.991_001'; # TRIAL
+$Yukki::Web::Router::VERSION = '0.991_002'; # TRIAL
 
-$Yukki::Web::Router::VERSION = '0.991001';use v5.24;
+$Yukki::Web::Router::VERSION = '0.991002';use v5.24;
 use utf8;
 use Moo;
 
@@ -12,6 +12,7 @@ use Yukki::Web::Router::Route;
 use Types::Standard qw( ArrayRef Str );
 use Type::Utils qw( class_type declare as where );
 use List::Util qw( all );
+use Yukki::Types qw( LoginName );
 
 use namespace::clean;
 
@@ -120,6 +121,36 @@ sub BUILD {
         ],
         target => $self->controller('Attachment'),
     ));
+
+    $self->add_route('admin/user/:action' => (
+        defaults => {
+            action  => 'list',
+            special => 'admin_user',
+        },
+        validations => {
+            action => qr/^(?:add|list)$/,
+        },
+        acl => [
+            [ read => { action => [ qw( list ) ] } ],
+            [ write => { action => [ qw( add ) ] } ],
+        ],
+        target => $self->controller('Admin::User'),
+    ));
+
+    $self->add_route('admin/user/:action/:login_name' => (
+        defaults => {
+            action  => 'edit',
+            special => 'admin_user',
+        },
+        validations => {
+            action     => qr/^(?:edit|remove)$/,
+            login_name => LoginName,
+        },
+        acl => [
+            [ write => { action => [ qw( edit remove ) ] } ],
+        ],
+        target => $self->controller('Admin::User'),
+    ));
 }
 
 1;
@@ -136,7 +167,7 @@ Yukki::Web::Router - send requests to the correct controllers, yo
 
 =head1 VERSION
 
-version 0.991_001
+version 0.991_002
 
 =head1 DESCRIPTION
 
