@@ -1,7 +1,7 @@
 package Yukki::Web::Settings;
-$Yukki::Web::Settings::VERSION = '0.991_001'; # TRIAL
+$Yukki::Web::Settings::VERSION = '0.991_002'; # TRIAL
 
-$Yukki::Web::Settings::VERSION = '0.991001';use v5.24;
+$Yukki::Web::Settings::VERSION = '0.991002';use v5.24;
 use utf8;
 use Moo;
 
@@ -51,7 +51,8 @@ has scripts => (
         [ qw(
             script/lib/jquery/jquery.js
             script/lib/jquery/jquery-ui.js
-            script/lib/jquery/jquery-fieldselection.js
+            script/lib/jquery/jquery.caret.js
+            script/lib/jquery/jquery.tag-editor.js
             script/lib/plupload/plupload.full.js
             script/lib/sha1/sha1.js
             script/yukki.js
@@ -72,6 +73,7 @@ has styles => (
         [ qw(
             style/yukki.css
             style/lib/jquery/jquery.css
+            style/lib/jquery/jquery.tag-editor.css
         ) ]
     },
 );
@@ -154,7 +156,7 @@ Yukki::Web::Settings - provides structure and validation to web settings in yukk
 
 =head1 VERSION
 
-version 0.991_001
+version 0.991_002
 
 =head1 DESCRIPTION
 
@@ -186,7 +188,8 @@ shell template. If not set, the defaults are:
   scripts:
       - script/lib/jquery/jquery.js
       - script/lib/jquery/jquery-ui.js
-      - script/lib/jquery/jquery-fieldselection.js
+      - script/lib/jquery/jquery.caret.js
+      - script/lib/jquery/jquery.tag-editor.js
       - script/lib/plupload/plupload.full.js
       - script/lib/sha1/sha1.js
       - script/yukki.js
@@ -194,6 +197,7 @@ shell template. If not set, the defaults are:
   styles:
       - style/yukki.css
       - style/lib/jquery/jquery.css
+      - style/lib/jquery/jquery.tag-editor.css
 
 As you can see, these are full paths and may be given as paths to foreign hosts.
 In order to keep Yukki working in good order, you will probaby want to include
