@@ -1,7 +1,7 @@
 package Yukki::Web::View::Page;
-$Yukki::Web::View::Page::VERSION = '0.991_001'; # TRIAL
+$Yukki::Web::View::Page::VERSION = '0.991_002'; # TRIAL
 
-$Yukki::Web::View::Page::VERSION = '0.991001';use v5.24;
+$Yukki::Web::View::Page::VERSION = '0.991002';use v5.24;
 use utf8;
 use Moo;
 
@@ -260,7 +260,7 @@ sub history {
 
     my $i = 0;
     return $self->render_page(
-        template => 'page/history.html',
+        template => $self->history_template,
         context  => $ctx,
         vars     => {
             'form_action' => join('/', '/page/diff', $vars->{repository}, $vars->{page}),
@@ -463,7 +463,7 @@ Yukki::Web::View::Page - render HTML for viewing and editing wiki pages
 
 =head1 VERSION
 
-version 0.991_001
+version 0.991_002
 
 =head1 DESCRIPTION
 
